==> developer-center-api-3.1.20-huan-20180822.093429-21-sources.jar: cn/com/duiba/developer/center/api/domain/dto/visualeditor/VisualEditorSkinTemplateDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.visualeditor;

import java.io.Serializable;
import java.util.Date;

/**
 * @author author
 */
public class  VisualEditorSkinTemplateDto implements Serializable {

    private static final long serialVersionUID = 1533881866524L;

    /**
     * 主键
     * 物理主键
     * isNullAble:0
     */
    private Long id;

    /**
     * 组件数据
     * isNullAble:1
     */
    private String dataJson;

    /**
     * 模板预览地址
     * isNullAble:1
     */
    private String previewUrl;

    /**
     * 名称
     * isNullAble:1
     */
    private String templateName;

    /**
     * 上下架标识( 0-隐藏 1-开启)
     */
    private Integer openStatus;
    /**
     * 定向状态(0-公用 1-定向)
     */
    private Integer direction;

    /**
     * 创建时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     * 修改时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return this.id;
    }

    public void setDataJson(String dataJson) {
        this.dataJson = dataJson;
    }

    public String getDataJson() {
        return this.dataJson;
    }

    public void setPreviewUrl(String previewUrl) {
        this.previewUrl = previewUrl;
    }

    public String getPreviewUrl() {
        return this.previewUrl;
    }

    public void setTemplateName(String templateName) {
        this.templateName = templateName;
    }

    public String getTemplateName() {
        return this.templateName;
    }

    public Integer getOpenStatus() {
        return openStatus;
    }

    public void setOpenStatus(Integer openStatus) {
        this.openStatus = openStatus;
    }

    public Integer getDirection() {
        return direction;
    }

    public void setDirection(Integer direction) {
        this.direction = direction;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return this.gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return this.gmtModified;
    }

    @Override
    public String toString() {
        return "VisualEditorSkinTemplate{" +
                "id='" + id + '\'' +
                "dataJson='" + dataJson + '\'' +
                "previewUrl='" + previewUrl + '\'' +
                "templateName='" + templateName + '\'' +
                "openStatus='" + openStatus + '\'' +
                "direction='" + direction + '\'' +
                "gmtCreate='" + gmtCreate + '\'' +
                "gmtModified='" + gmtModified + '\'' +
                '}';
    }
}

==> developer-center-api-3.1.24-huan-20180828.062734-14-sources.jar: cn/com/duiba/developer/center/api/domain/dto/visualeditor/VisualEditorSkinTemplateDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.visualeditor;

import java.io.Serializable;
import java.util.Date;

/**
 * @author author
 */
public class  VisualEditorSkinTemplateDto implements Serializable {

    private static final long serialVersionUID = 1533881866524L;

    /**
     * 主键
     * 物理主键
     * isNullAble:0
     */
    private Long id;

    /**
     * 组件数据
     * isNullAble:1
     */
    private String dataJson;

    /**
     * 模板预览地址
     * isNullAble:1
     */
    private String previewUrl;

    /**
     * 名称
     * isNullAble:1
     */
    private String templateName;

    /**
     * 上下架标识( 0-隐藏 1-开启)
     */
    private Integer openStatus;
    /**
     * 定向状态(0-公用 1-定向)
     */
    private Integer direction;
    /**
     * 修改人id
     */
    private Long modifyAdminId;
    /**
     * 修改人
     */
    private String modifyName;
    /**
     * 创建时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     * 修改时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtModified;

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    public Long getModifyAdminId() {
        return modifyAdminId;
    }

    public void setModifyAdminId(Long modifyAdminId) {
        this.modifyAdminId = modifyAdminId;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return this.id;
    }

    public void setDataJson(String dataJson) {
        this.dataJson = dataJson;
    }

    public String getDataJson() {
        return this.dataJson;
    }

    public void setPreviewUrl(String previewUrl) {
        this.previewUrl = previewUrl;
    }

    public String getPreviewUrl() {
        return this.previewUrl;
    }

    public void setTemplateName(String templateName) {
        this.templateName = templateName;
    }

    public String getTemplateName() {
        return this.templateName;
    }

    public Integer getOpenStatus() {
        return openStatus;
    }

    public void setOpenStatus(Integer openStatus) {
        this.openStatus = openStatus;
    }

    public Integer getDirection() {
        return direction;
    }

    public void setDirection(Integer direction) {
        this.direction = direction;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return this.gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return this.gmtModified;
    }

    @Override
    public String toString() {
        return "VisualEditorSkinTemplate{" +
                "id='" + id + '\'' +
                "dataJson='" + dataJson + '\'' +
                "previewUrl='" + previewUrl + '\'' +
                "templateName='" + templateName + '\'' +
                "openStatus='" + openStatus + '\'' +
                "direction='" + direction + '\'' +
                "gmtCreate='" + gmtCreate + '\'' +
                "gmtModified='" + gmtModified + '\'' +
                '}';
    }
}
